@@ -12,7 +12,7 @@ First, add `dateless` as a dependency in your project's Cargo.toml:
 
 ```toml
 [dependencies]
-dateless = "0.2.2"
+dateless = "0.3.0"
 ```
 
 And then, you can start with creating a calendar:
@@ -35,8 +35,8 @@ fn main() {
     let mut calendar = Calendar::new();
 
     let event = EventPartial::new(String::from("Anne's birthday"))
-        .with_period(EventPeriod::WholeDays(Utc::today(), Utc::today()))
-        .with_cyclicity(EventCyclicity::EveryWeek)
+        .whole_day(Utc::today())
+        .daily()
         .complete();
 
     calendar.add_event(event);
@@ -56,8 +56,8 @@ fn main() {
     let mut calendar = Calendar::new();
 
     let event = EventPartial::new(String::from("Anne's birthday"))
-        .with_period(EventPeriod::WholeDays(Utc::today(), Utc::today()))
-        .with_cyclicity(EventCyclicity::EveryWeek)
+        .whole_day(Utc::today())
+        .daily()
         .complete();
 
     calendar.add_event(event);
@@ -89,14 +89,15 @@ It prints to `stdout`:
 mod codegen;
 
 mod calendar;
+mod chrono;
 mod event;
 pub mod prelude;
 
 #[cfg(test)]
 mod test;
 
-#[macro_use]
-extern crate optional_struct;
+#[cfg(feature = "serde_support")]
+mod serde;
 
 pub use calendar::Calendar;
-pub use event::{EventCyclicity, EventOccurrence, EventPartial, EventPeriod};
+pub use event::{Cyclicity, Event, EventOccurrence, EventPartial, Period};
